@@ -1,12 +1,13 @@
 #' Plots of tree profiles with gaps and fuel layers base height (fbh)
 #' @description This function plots gaps and fuel layers base height (fbh) in the vertical tree profile (VTP).
-#' @usage get_plots_gap_fbh (LAD_profiles,depth_metrics)
+#' @usage get_plots_gap_fbh (LAD_profiles,gap_cbh_metrics,min_height=1.5)
 #' @param LAD_profiles original tree Leaf Area Density (LAD) profile (output of [lad.profile()] function in the \emph{leafR} package.
 #' An object of the class text
-#' @param depth_metrics tree metrics with gaps (distances), fuel base heights and depths (output of [get_depths()] function).
-#' An object of the class text
+#' @param gap_cbh_metrics data frame with gaps (distances) and fuel base heights (output of [get_gaps_fbhs()] function).
+#' An object of the class text.
+#' @param min_height Numeric value for the actual minimum base height (in meters).
 #' @return A plot drawing by lines the height of gaps and fuel layers bases in tiff format.
-#' @author Olga Viedma, Carlos Silva and JM Moreno
+#' @author Olga Viedma, Carlos Silva, JM Moreno and A.T. Hudak
 #'
 #' @examples
 #' library(ggplot2)
@@ -17,13 +18,13 @@
 #' header = TRUE)
 #' LAD_profiles$treeID <- factor(LAD_profiles$treeID)
 #'
-#' # Before running this example, make sure to run get_depths().
+#' # Before running this example, make sure to run get_gaps_fbhs().
 #' if (interactive()) {
-#' depth_metrics <- get_depths()
-#' LadderFuelsR::depth_metrics$treeID <- factor(LadderFuelsR::depth_metrics$treeID)
+#' gap_cbh_metrics <- get_gaps_fbhs()
+#' LadderFuelsR::gap_cbh_metrics$treeID <- factor(LadderFuelsR::gap_cbh_metrics$treeID)
 #'
 #' # Generate plots for gaps and fbhs
-#' plots_gaps_fbhs <- get_plots_gap_fbh(LAD_profiles, depth_metrics)
+#' plots_gaps_fbhs <- get_plots_gap_fbh(LAD_profiles, gap_cbh_metrics, min_height=1.5)
 #' }
 #' @importFrom dplyr select_if group_by summarise summarize mutate arrange rename rename_with filter slice slice_tail ungroup distinct
 #' across matches row_number all_of vars
@@ -32,25 +33,50 @@
 #' @importFrom stats ave dist lm na.omit predict quantile setNames smooth.spline
 #' @importFrom utils tail
 #' @importFrom tidyselect starts_with everything one_of
-#' @importFrom stringr str_extract str_match str_detect
+#' @importFrom stringr str_extract str_match str_detect str_remove_all
 #' @importFrom tibble tibble
 #' @importFrom tidyr pivot_longer fill
 #' @importFrom gdata startsWith
 #' @importFrom ggplot2 aes geom_line geom_path geom_point geom_polygon geom_text geom_vline ggtitle coord_flip theme_bw
 #' theme element_text xlab ylab ggplot
-#' @seealso \code{\link{get_depths}}
+#' @seealso \code{\link{get_gaps_fbhs}}
 #' @export
-get_plots_gap_fbh <- function (LAD_profiles,depth_metrics) {
+get_plots_gap_fbh <- function (LAD_profiles,gap_cbh_metrics,min_height=1.5) {
 
   df_orig<-LAD_profiles
 
+
+  if(min_height==0){
+    min_height <-0.5
+
+    # Ensure the column starts with a negative value
+    if (df_orig$height[1] < min_height) {
+      # Calculate the shift value
+      shift_value <- abs(df_orig$height[1])
+
+      # Adjust the column to start from 0
+      df_orig$height <- df_orig$height + shift_value
+    }
+
+
+    # Ensure the column starts with a negative value
+    if (df_orig$height[1] > min_height) {
+      # Calculate the shift value
+      shift_value1 <- abs(df_orig$height[1])
+
+      # Adjust the column to start from 0
+      df_orig$height <- df_orig$height - shift_value1
+    }
+  }
+
+
   df_orig$treeID<-factor(df_orig$treeID)
   treeID<-factor(df_orig$treeID)
 
   trees_name1a<- as.character(df_orig$treeID)
   trees_name3<- factor(unique(trees_name1a))
 
-  df_metrics<- depth_metrics
+  df_metrics<- gap_cbh_metrics
 
 
   plot_list <- list()
